@@ -17,21 +17,20 @@ class IDispatcher:
     channels: Dict[str, IChannel]
     events_listeners: Dict[str, EventListener]
     scheduler: TaskScheduler
-    with_scheduler: bool
 
     collected_metrics: Dict[str, Dict[str, BaseMetric]]
     with_metrics: bool
 
     _msg_global_index: int
 
-    def __init__(self, with_scheduler: bool = False, with_metrics: bool = False):
-        self.with_scheduler = with_scheduler
+    def __init__(self, scheduler: TaskScheduler = None, with_metrics: bool = False):
+        self.scheduler = scheduler
         self.with_metrics = with_metrics
         self.channels = {}
         self.events_listeners = {}
         self._msg_global_index = 0
-        if self.with_scheduler:
-            self.scheduler = TaskScheduler(self.broadcast)
+        if self.scheduler:
+            self.scheduler.produce_method = self.broadcast
             self.add_event_listener(TaskIMessage.message_type, self.scheduler.add_task)
         if with_metrics:
             self.collected_metrics = {}
@@ -138,6 +137,6 @@ class IDispatcherIsolate(Isolate):
         super().__init__(name, **kwargs)
 
     async def work(self, **kwargs) -> None:
-        if self.dispatcher.with_scheduler:
+        if self.dispatcher.scheduler:
             self.dispatcher.scheduler.perform()
         await asyncio.wait(self.dispatcher.perform())
